@@ -180,6 +180,11 @@ class TrayIcon (QtGui.QSystemTrayIcon):
             QtGui.QIcon.setThemeName(old_theme_name)
 
     def generation_actions(self):
+        _("About")
+        _("Report a Bug")
+        _("Program settings")
+        _("Update System")
+        _("Exit Program")
         self.actions = {
                    'help': {
                        'icons': ['help-about', 'help-browser'],
